package analytics;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Map;

import geog.OnSegmentLocation;
import geog.Segment;
import geog.Street;
import geog.io.MapReader;

import java.util.List;

/**
 * A Geocoder object can be used to determine the longitude/latitude of one or
 * more addresses.
 * 
 * @author CS159 Professors, James Madison University
 * @version 1
 */
public class Geocoder {

    private Map<String, Street> streets;

    /**
     * Explicit Value Constructor.
     * 
     * @param file The name of the file containing the street network
     * @throws IOException if a problem occurs
     */
    public Geocoder(String file) throws IOException {
        Map<String, Segment> segments;
        
        segments = MapReader.readSegments(file + ".seg");
        streets = MapReader.readStreets(file + ".str", segments);
    }

    /**
     * Determine the longitude/latitude of an address.
     * 
     * @param name The street name
     * @param number The number on the street
     * @return A List of OnSegmentLocation objects
     */
    public List<OnSegmentLocation> fromAddress(String name, int number) {

        List<OnSegmentLocation> result;

        Street street = streets.get(name);
        if (street != null) {
            result = street.geocode(number);
            Collections.sort(result);
        } else {
            result = new ArrayList<OnSegmentLocation>();
        }
        return result;
    }
}
