package geog;

import java.util.ArrayList;
import java.util.List;

/**
 * A Street is a collection of Segment objects.
 *
 * An ArrayList is used because it is resizable and there is no need to use a
 * non-integer index.
 *
 * @author CS159 Professors, James Madison University
 * @version 1
 */
public class Street {
    
    private List<Segment> segments;
    private String name;
    
    /**
     * Default Constructor.
     * 
     * @param name The name of the Street
     */
    public Street(String name) {
        this.name = name;
        segments = new ArrayList<Segment>();
    }

    /**
     * Add a Segment to this Street.
     *
     * @param seg The Segment to add
     */
    public void add(Segment seg) {
        segments.add(seg);
    }

    /**
     * Geocode (using linear interpolation) the given house number.
     *
     * @param number The house number of interest
     * @return null if not found; the linear interpolation otherwise
     */
    public List<OnSegmentLocation> geocode(int number) {
        List<OnSegmentLocation> result;
        OnSegmentLocation location;

        result = new ArrayList<OnSegmentLocation>();
        for (Segment segment: segments) {
            location = segment.interpolate(number);
            if (location != null) {
                result.add(location);
            }
        }
        return result;
    }
    
    /**
     * Get the name.
     * 
     * @return The name
     */
    public String getName() {
        return name;
    }
}
