package geog.io;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.File;
import java.io.IOException;
import java.util.Map;
import java.util.HashMap;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;

import geog.Segment;
import geog.Street;

/**
 * A utility class for reading collections of Segment and Street objects.
 *
 * @author PCS159 Professors, James Madison University
 * @version 1
 */
public class MapReader {

    /**
     * Read a "database" of Segment objects from from the given file.
     *
     * @param file The name of the file
     * @return The "database"
     * @throws IOException If the file can't be read
     */
    public static Map<String, Segment> readSegments(String file) 
            throws IOException {
        BufferedReader in;
        Map<String, Segment> segments;
        Segment segment;
        String id, line;
        
        segments = new HashMap<String, Segment>();
        
        // Read the .seg file
        in = new BufferedReader(new FileReader(new File(file)));
        while ((line = in.readLine()) != null) {
            try {
                segment = new Segment();
                id = segment.fromTSV(line);
                segments.put(id, segment);
            } catch (NoSuchElementException nsee) {
                // Ignore the Segment
            } catch (NumberFormatException nfee) {
                // Ignore the Segment
            }
        }
        in.close();
        
        return segments;
    }


    /**
     * Read a "database" of Street objects from from the given file.
     *
     * @param file The name of the file
     * @param segments The Map from segment IDs to Segment objects
     * @return The "database"
     * @throws IOException If the file can't be read
     */
    public static Map<String, Street> readStreets(String file, 
            Map<String, Segment> segments) throws IOException {
        BufferedReader in;
        Map<String, Street> streets;
        int n;
        Segment segment;
        Street street;
        String id, line, name;
        StringTokenizer st;

        streets = new HashMap<String, Street>();
        in = new BufferedReader(new FileReader(new File(file)));
        while ((line = in.readLine()) != null) {
            st = new StringTokenizer(line, "\t");
            name = st.nextToken();
            n = Integer.parseInt(st.nextToken());
            street = new Street(name);
            for (int i = 0; i < n; i++) {
                id = in.readLine();
                segment = segments.get(id);
                if (segment != null) {
                    street.add(segment);
                }
            }
            streets.put(name, street);
        }
        in.close();
        
        return streets;
    }
}
